@@ -23,7 +23,7 @@ my $y     = $f->{'YRES'} / 2;
 my $start = time;
 
 $f->set_color({'red' => 255, 'green' => 0, 'blue' => 0});
-for (my $radius = 10 ; $radius < $y ; $radius += 4) {
+for (my $radius = 10 ; $radius < $y ; $radius += 10) {
     $f->circle({'x' => $x, 'y' => $y, 'radius' => $radius, 'filled' => 1});
 }
 
@@ -32,7 +32,7 @@ push(@t, sprintf('%.02f', time - $start));
 $start = time;
 
 $fm->set_color({'red' => 0, 'green' => 0, 'blue' => 255});
-for (my $radius = 10 ; $radius < $y ; $radius += 4) {
+for (my $radius = 10 ; $radius < $y ; $radius += 10) {
     $fm->circle({'x' => $x, 'y' => $y, 'radius' => $radius, 'filled' => 1});
 }
 
@@ -40,8 +40,8 @@ push(@t, sprintf('%.02f', time - $start));
 
 $f->set_color({'red' => 255, 'green' => 255, 'blue' => 0});
 $start = time;
-for (my $xx = $y ; $xx >= 0 ; $xx--) {
-    $f->box({'x' => $xx, 'y' => $xx, 'xx' => $f->{'XRES'} - $xx, 'yy' => $f->{'YRES'} - $xx});
+for (my $xx = $y ; $xx >= 0 ; $xx-=10) {
+    $f->box({'x' => $xx, 'y' => $xx, 'xx' => $f->{'XRES'} - $xx, 'yy' => $f->{'YRES'} - $xx, 'filled' => 1});
 }
 
 push(@t, sprintf('%.02f', time - $start));
@@ -49,8 +49,8 @@ push(@t, sprintf('%.02f', time - $start));
 $fm->set_color({'red' => 0, 'green' => 255, 'blue' => 255});
 $start = time;
 
-for (my $xx = $y ; $xx >= 0 ; $xx--) {
-    $fm->box({'x' => $xx, 'y' => $xx, 'xx' => $fm->{'XRES'} - $xx, 'yy' => $fm->{'YRES'} - $xx});
+for (my $xx = $y ; $xx >= 0 ; $xx-=10) {
+    $fm->box({'x' => $xx, 'y' => $xx, 'xx' => $fm->{'XRES'} - $xx, 'yy' => $fm->{'YRES'} - $xx, 'filled' => 1});
 }
 
 push(@t, sprintf('%.02f', time - $start));
@@ -58,7 +58,7 @@ push(@t, sprintf('%.02f', time - $start));
 $start = time;
 $f->set_color({'red' => 0, 'green' => 255, 'blue' => 0});
 
-foreach my $xx (0 .. $f->{'XRES'}) {
+for (my $xx=0; $xx < $f->{'XRES'}; $xx += ($f->{'XRES'}/100)) {
     $f->line({'x' => $xx, 'y' => 0, 'xx' => $xx, 'yy' => $f->{'YRES'}});
 }
 push(@t, sprintf('%.02f', time - $start));
@@ -66,8 +66,8 @@ push(@t, sprintf('%.02f', time - $start));
 $start = time;
 $fm->set_color({'red' => 255, 'green' => 0, 'blue' => 255});
 
-foreach my $xx (0 .. $f->{'XRES'}) {
-    $fm->line({'x' => $xx, 'y' => 0, 'xx' => $xx, 'yy' => $f->{'YRES'}});
+for (my $xx=0; $xx < $fm->{'XRES'}; $xx += ($fm->{'XRES'}/100)) {
+    $fm->line({'x' => $xx, 'y' => 0, 'xx' => $xx, 'yy' => $f->{'YRES'},'filled' => 1});
 }
 push(@t, sprintf('%.02f', time - $start));
 $f->cls('ON');
